# manygame - 命令行小游戏库

一个轻量级的Python库，快速的玩到小游戏。

## 🛠️ 功能
- 纸牌（比大小）
- 猜数字
- 石头剪刀布
- 逃出迷宫

## 📦 安装
```bash
pip install manygame
```

## 卸载
```bash
pip uninstall manygame
```

## 执行
```python
import manygame
manygame.card() #纸牌游戏
manygame.numbergame() #猜数字
manygame.playmg() #逃出迷宫
manygame.playsjb() #石头剪刀布
```

## Update log

`1.0.0` first release

# 谢谢使用！后续还会有更多游戏！